summaryrefslogtreecommitdiffstats
path: root/src/newbasketdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/newbasketdialog.h')
-rw-r--r--src/newbasketdialog.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/newbasketdialog.h b/src/newbasketdialog.h
index a5c9886..07a081a 100644
--- a/src/newbasketdialog.h
+++ b/src/newbasketdialog.h
@@ -25,7 +25,7 @@
#include <kiconview.h>
#include <tqmap.h>
-class KIconButton;
+class TDEIconButton;
class TQLineEdit;
class TQDragObject;
class TQListViewItem;
@@ -34,16 +34,16 @@ class Basket;
class KColorCombo2;
/** The class KIconView allow to drag items. We don't want to, so we disable it.
* This class also unselect the selected item when the user right click an empty space. We don't want to, so we reselect it if that happens.
* @author Sébastien Laoût
*/
-class SingleSelectionKIconView : public KIconView
+class SingleSelectionTDEIconView : public TDEIconView
{
Q_OBJECT
public:
- SingleSelectionKIconView(TQWidget *parent = 0, const char *name = 0, WFlags f = 0);
+ SingleSelectionTDEIconView(TQWidget *parent = 0, const char *name = 0, WFlags f = 0);
TQDragObject* dragObject();
TQIconViewItem* selectedItem() { return m_lastSelected; }
private slots:
@@ -91,10 +91,10 @@ class NewBasketDialog : public KDialogBase
private:
int populateBasketsList(TQListViewItem *item, int indent, int index);
NewBasketDefaultProperties m_defaultProperties;
- KIconButton *m_icon;
+ TDEIconButton *m_icon;
TQLineEdit *m_name;
KColorCombo2 *m_backgroundColor;
- KIconView *m_templates;
+ TDEIconView *m_templates;
TQComboBox *m_createIn;
TQMap<int, Basket*> m_basketsMap;
};
@@ -34,16 +34,16 @@ class Basket;
class KColorCombo2;
-/** The class KIconView allow to drag items. We don't want to, so we disable it.
+/** The class TDEIconView allow to drag items. We don't want to, so we disable it.
* This class also unselect the selected item when the user right click an empty space. We don't want to, so we reselect it if that happens.
* @author Sébastien Laoût